'use strict';

/**
 * Html页面多语言化。
 *
 * 在Html页面中只需先引用一个JQuery文件：
 * 例如：<script src="http://libs.baidu.com/jquery/1.8.1/jquery.min.js"></script>
 * 
 * 在引用本JS文件
 * 例如：<script src="./zh-cn.bilingualism.js"></script>
 *
 * 如果你想多语言化一个Html页面，你应该做两件事:
 * 1. 在HTML标签中，加入 data-sw-translate="" 标记
 *      例如：<h6 data-sw-translate="">Hello World</h6>
 * 2. 然后在下面的 window.SwaggerTranslator.learn 中添加中英文对应关系
 *      添加： "Hello World": "你好，世界",
 */
window.SwaggerTranslator = {
	_words: [],

	translate: function() {
		var $this = this;
		$('[data-sw-translate]').each(function() {
			$(this).html($this._tryTranslate($(this).html()));
			$(this).val($this._tryTranslate($(this).val()));
			$(this).attr('title', $this._tryTranslate($(this).attr('title')));
		});
	},

	_tryTranslate: function(word) {
		return this._words[$.trim(word)] !== undefined ? this._words[$.trim(word)] : word;
	},

	learn: function(wordsMap) {
		this._words = wordsMap;
	}
};
/* jshint quotmark: double */
window.SwaggerTranslator.learn({
	
	// 登录
	"login_title_login": "Login",
	"login_desc_register": "Register",
	"login_desc_forget": "Forgot Password",
	
	// 注册
	"login_title_register": "Register",
	"login_content_desc1": "+86",
	"login_content_phone": "Send to phone",
	"login_content_mail": "Send to email",
	"login_nextBtn": "Next",
	"login_register_mail": "Register with Email",
	"login_register_mail": "Register with Phone",
	"login_service_desc1": "Accept the",
	"login_service_desc2": "Terms of Service",
	
	// 注册里面的用户信息
	"register_sexType": "Gender",
	"register_birthday": "Birthday",
	"register_done": "Done",
	
	// 首页
	"index_device": "Device",
	"index_shop": "E-Mall",
	"index_mine": "Me",
	"index_HJY": "Air Monitor",
	"index_XFJ": "Clean Fresh Air Machine",
	"index_FB": "AirPro Fresh",
	//添加设备
	"index_menu_add": "Add Device",
	// 环境仪添加设备
	"hjy_add_info1": "1. Enter the \"Internet Setting\" interface, turn on WiFi to connect the device to the internet.",
	"hjy_add_info2": "2. Enter the \"Engineer’s Setting\" interface, go to \"System Parameters\" and enter the MAC address in the dialogue box, note that the semicolon is not needed. After the MAC address is entered, press \"Bind\".",
	"hjy_add_macStr": "MAC：",
	"hjy_add_bind": "Bind",

	// 肺保、新风机添加设备
	"fb_add_descInfo1": "1. Fill in the user information",
	"fb_add_descInfo2": "2. Power on the WiFi module and make sure it is in the same network as your cell phone. Press the button on the WiFi module",
	"fb_add_descInfo3": "3. When the green light next to the button blinks, enter the network password in box below, press \"Configurate\"",
	"fb_add_ff_desc2": "2.Power on the device, ensure that the device and the mobile phone are in the same network, and then set the device to critical state",
	"fb_add_ff_desc3": "3.Press and hold the wind speed button of the device until the blue light flashes and release it, enter the network password in the password box below, and click \"Configure\"",
	"fb_add_ff_desc4": "4.After the blue indicator blinks, if the red indicator is displayed for a short time, the network configuration times out; if the green indicator is displayed for a short time, the network configuration succeeds",
	"fb_add_fe_desc4": "4.After the blue indicator blinks, if the yellow indicator is displayed for a short time, the network configuration times out; if the green indicator is displayed for a short time, the network configuration succeeds",
	"fb_add_fe_desc5": "5.The device does not support WiFi signals in the 5GHz band. Please select the 2.4GHz band to complete the network configuration.",
	"fb_add_locationInfo": "Address",
	"fb_add_locationRequired": "（Required）",
	"fb_add_position": "Automatic location finder",
	"fb_add_province": "Province",
	"fb_add_city": "City",
	"fb_add_area": "District",
	"fb_add_street": "Street",
	"fb_add_wifiSetting": "Wireless Configuration",
	"fb_add_passWord": "Password:",
	"fb_add_bind": "Configurate",
	"fb_add_wifiPass": "Remember password",

	// 设备列表
	"devlist_func_title": "Function Selection",
	"devlist_func_model": "Model Selection",
	"devlist_func_reName": "Rename",
	"devlist_func_share": "Share",
	"devlist_func_unsharing": "Unshare",
	"devlist_func_unbind": "Unbind",

	// 环境仪
	"hjy_PM_title1": "PM2.5",
	"hjy_PM_title2": "Inhalable Particles",
	"hjy_PM_unit": "μg/m³",
	"hyj_PM_check": "Detect",
	"hjy_PM_numInfo": "Laser Count（Quantity/L）",
	"hjy_PM_10": "PM10 Above",
	"hjy_CO_title": "",
	"hjy_EMR_title": "EMR",
	"hjy_EMR_desc": "Real-Time",
	// 环境仪城市界面
	"hjy_city_title": "PM2.5 City Ranking",
	"hjy_city_temperature": "Outdoor temperature",
	"hjy_city_title2": "The country's best rating today",
	"hjy_city_tabTitle1": "Ranking",
	"hjy_city_tabTitle2": "City",
	"hjy_city_tabTitle3": "PM2.5μg/m³",
	"hjy_city_tabTitle4": "Level",
	"hjy_city_previous": "Previous",
	"hjy_city_next": "Next",
	"hjy_city_desc1": "*Data from",
	"hjy_city_desc2": "CNEMC",
	"hjy_city_desc3": "update at",
	
	// 新风肺保
	"fb_main_level": "Level",
	"fb_main_desc1": "The coarse filter has been used for",
	"fb_main_desc2": "The HEPA filter has been used for",
	"fb_main_reset": "Reset",
	"fb_main_timeS": "hrs",
	"fb_main_timeS2": "hrs",
	// 新风肺保设置页面
	"fb_set_title1": "Parameter Setting",
	"fb_set_t1_cx": "Coarse filter cleaning cycle:",
	"fb_set_t1_gx": "HEPA filter cleaning cycle:",
	"fb_set_t1_fctj": "Particle threshold value:",
	"fb_set_t1_fcbj": "Particle alert value:",
	"fb_set_t1_tj": "threshold value:",
	"fb_set_t1_bj": "alert value:",
	"fb_set_title2": "Auto off after people left the premises",
	"fb_set_flag_enable": "Enable",
	"fb_set_flag_disable": "Disable",
	"fb_set_title3": "Particle threshold adjustment",
	"fb_set_title4": "threshold adjustment",
	
	// 新风机首页
	"xfj_main_title1": "Device",
	"xfj_main_title2": "Energy Cons.",
	"xfj_main_title3": "Fault",
	// 新风机主页
	"xfj_li_newWind": "Fresh Air",
	"xfj_li_co2": "",
	"xfj_li_indoor": "Indoor",
	"xfj_li_outdoor": "Outdoor",
	"xfj_li_exhaust": "Exhaust",
	"xfj_model_title": "Control Mode",
	"xfj_model_control": "Freshness Auto Control",
	"xfj_model_default": "Normal",
	"xfj_model_max": "High Speed",
	"xfj_model_min": "Mute",
	"xfj_model_nobody": "Unoccupied",
	"xfj_model_winter": "Extremely Chilly Day",
	"xfj_desc_cx": "The coarse filter has been used for:",
	"xfj_desc_jdcc": "The electrostatic cleaner has been used for:",
	"xfj_desc_gx": "The HEPA filter has been used for:",
	"xfj_desc_small": "(Recommended cleaning cycle: 720 hrs)",
	// 新风机二级页面
	"xfj_set_cx": "Coarse filter usage time",
	"xfj_set_jd": "Electrostatic cleaner usage time",
	"xfj_set_gx": "HEPA usage time",
	"xfj_set_retBtn": "Reset",
	"xfj_set_outDoorT": "Default city for outdoor data",
	"xfj_set_cityT": "City",
	"xfj_set_fc": "Particle threshold adjustment",
	"xfj_set_flag_enable": "Enable",
	"xfj_set_flag_disable": "Disable",
	// 新风机能耗
	"xfj_ec_title": "Energy Consumption",
	"xfj_ec_tabT1": "Time",
	"xfj_ec_tabT2": "Heat Recovery",
	"xfj_ec_tabT3": "Fan Power Consumption",
	"xfj_ec_cellSS": "Real Time (kW)",
	"xfj_ec_cellXL": "Efficiency",
	"xfj_ec_cellTD": "Today (kWh)",
	"xfj_ec_cellTM": "This Month (kWh)",
	"xfj_ec_cellTY": "This Year (kWh)",
	"xfj_ec_cellLY": "Last Year (kWh)",
	// 新风机故障
	"xfj_fault_title": "Fault",
	
	// 二维码扫描
	"scan_title": "Scan QR Code",
	"scan_photo": "Album",
	"scan_cancel": "Cancel",

	/*我的模块*/
	"mine_accountM": "Account Management",
	"mine_infoM": "Information",
	"mine_helpM": "Help",
	"mine_salesInfo": "After-sales Maintenance",
	"mine_aboutM": "About",
	"mine_buyS": "Purchase",
	"mine_about_Version": "Current Version: ",
	
	// 账号管理
	"mine_accountM_info": "Register",
	"mine_accountM_locationInfo": "Address",
	"mine_accountM_position": "Automatic location finder",
	"mine_accountM_province": "Province",
	"mine_accountM_city": "City",
	"mine_accountM_area": "District",
	"mine_accountM_street": "Street",
	"mine_accountM_saveBtn": "Save",
	
	// 售后维修
	"mine_sales_deviceM": "Device model:",
	"mine_sales_pDesc": "Fault description:",
	"mine_sales_photoT": "Photo:",
	"mine_sales_photoDesc": "（Maximum 3 photos to be uploaded）",
	"mine_sales_phoneNum": "Contact number:",
	"mine_sales_name": "Contact person:",
	"mine_sales_address": "Contact address:",
	"mine_sales_submit": "Submit",
	
	// 使用帮助
	"mine_help_text1": "1. Register: Please use your mobile number (or email) to register, during which process your phone (or email) will receive a verification code. Enter the verification code and your desired password, submit to complete registration.",
	"mine_help_text2": "2. Forgot password: To reset forgotten password, press \"Forgot Password\" in the main interface. Provide your registered mobile number (or email), and enter the verification code received before fill in the new password.",
	"mine_help_text3": "3. Change password: You can change the password by the same process of \"Forgot Password\".",
	"mine_help_text4": "4. Device binding: Connect the device to be bound to WiFi, then choose the corresponding option (Air Monitor, Clean Fresh Air Machine, AirPro Fresh) in the \"Device\" interface. The MAC address is needed to be filled in for the Air Monitor while both the location information and the WiFi password are needed for the other two devices.",
	"mine_help_text5": "5. Device control: After the device is bound, you can use your mobile phone to control, operate and extract information from the bound device remotely in another network. Make sure the Air Monitor is in charging mode, for the network will be cut off in standby mode.",
	"mine_help_text6": "6. Control sharing: All bound devices can be shared and controlled by multiple users. The control sharing invitation is initiated by the bound user to registered users (registered users can be granted with similar device control permissions as the bound user without binding the device). The invited users can accept, reject the invitation, or cancel the accepted shared control.",
	"mine_help_text7": "7. Software update: The software automatically detects new version, and reminds the user to download and update.",
	
	// 其他
	"other_cancel": "Cancel",
	"other_sure": "OK",
	"other_selectT": "Please select",
});


$(function() {
	window.SwaggerTranslator.translate();
});
