'use strict';

/**
 * Html页面多语言化。
 *
 * 在Html页面中只需先引用一个JQuery文件：
 * 例如：<script src="http://libs.baidu.com/jquery/1.8.1/jquery.min.js"></script>
 * 
 * 在引用本JS文件
 * 例如：<script src="./zh-cn.bilingualism.js"></script>
 *
 * 如果你想多语言化一个Html页面，你应该做两件事:
 * 1. 在HTML标签中，加入 data-sw-translate="" 标记
 *      例如：<h6 data-sw-translate="">Hello World</h6>
 * 2. 然后在下面的 window.SwaggerTranslator.learn 中添加中英文对应关系
 *      添加： "Hello World": "你好，世界",
 */
window.SwaggerTranslator = {
	_words: [],

	translate: function() {
		var $this = this;
		$('[data-sw-translate]').each(function() {
			$(this).html($this._tryTranslate($(this).html()));
			$(this).val($this._tryTranslate($(this).val()));
			$(this).attr('title', $this._tryTranslate($(this).attr('title')));
		});
	},

	_tryTranslate: function(word) {
		return this._words[$.trim(word)] !== undefined ? this._words[$.trim(word)] : word;
	},

	learn: function(wordsMap) {
		this._words = wordsMap;
	}
};
/* jshint quotmark: double */
window.SwaggerTranslator.learn({

	// 登录
	"login_title_login": "登录",
	"login_desc_register": "注册账号",
	"login_desc_forget": "忘记密码",

	// 注册
	"login_title_register": "注册",
	"login_content_desc1": "中国+86",
	"login_content_phone": "发送到手机",
	"login_content_mail": "发送到邮箱",
	"login_nextBtn": "下一步",
	"login_register_mail": "邮箱注册",
	"login_register_mail": "手机号注册",
	"login_service_desc1": "我已经阅读并同意",
	"login_service_desc2": "服务声明",

	// 注册里面的用户信息
	"register_sexType": "性别",
	"register_birthday": "生日",
	"register_done": "完成",

	// 首页
	"index_device": "设备",
	"index_shop": "商城",
	"index_mine": "我的",
	"index_HJY": "环境仪",
	"index_XFJ": "洁净新风机",
	"index_FB": "新风肺保",
	//添加设备
	"index_menu_add": "添加设备",
	// 环境仪添加设备
	"hjy_add_info1": "1. 打开远大环境仪,进入\"网络设置\",打开WIFI将设备联网.",
	"hjy_add_info2": "2. 进入到工程师设置页面,选中\"系统参数\",将MAC地址输入下方地址码框中,\":\"不用输入,输入完成后点击\"绑定\"按钮,完成设备绑定.",
	"hjy_add_macStr": "地址码：",
	"hjy_add_bind": "绑定",

	// 肺保、新风机添加设备
	"fb_add_descInfo1": "1. 填写完整的用户信息",
	"fb_add_descInfo2": "2. 把WIFI模块通电,确定WIFI模块与手机在同一网络,再点击WIFI模块上按键",
	"fb_add_descInfo3": "3. WIFI模块按键旁边的绿灯闪烁后,在下方密码框中输入网络密码,再点击\"配置\"按键即可",
	"fb_add_ff_desc2": "2. 将设备通电,确定设备和手机在同一网络内,再将设备调至关机状态",
	"fb_add_ff_desc3": "3. 长按设备风速档按键,至蓝灯闪烁后松开,在下方密码框中输入网络密码,再点击\"配置\"按键即可",
	"fb_add_ff_desc4": "4. 在蓝灯闪烁结束后,短暂显示红灯,则配网超时,短暂显示绿灯,则配网成功",
	"fb_add_fe_desc4": "4. 在蓝灯闪烁结束后,短暂显示黄灯,则配网超时,短暂显示绿灯,则配网成功",
	"fb_add_fe_desc5": "5. 设备不支持5GHz频段的WiFi信号,请选用2.4GHz频段完成配网",
	"fb_add_locationInfo": "地址信息",
	"fb_add_locationRequired": "（必填）",
	"fb_add_position": "自动定位",
	"fb_add_province": "省份：",
	"fb_add_city": "城市：",
	"fb_add_area": "区/县：",
	"fb_add_street": "街道：",
	"fb_add_wifiSetting": "无线配置",
	"fb_add_passWord": "密码:",
	"fb_add_bind": "配置",
	"fb_add_wifiPass": "记住密码",

	// 设备列表
	"devlist_func_title": "功能选择",
	"devlist_func_model": "机型选择",
	"devlist_func_reName": "重命名",
	"devlist_func_share": "共享设备",
	"devlist_func_unsharing": "解除共享",
	"devlist_func_unbind": "解除绑定",

	// 环境仪
	"hjy_PM_title1": "PM2.5粉尘",
	"hjy_PM_title2": "可吸入颗粒物",
	"hjy_PM_unit": "微克/立方米（μg/m³）",
	"hyj_PM_check": "马上<br>检测",
	"hjy_PM_numInfo": "激光计数 个/升（L）",
	"hjy_PM_10": "PM10以上",
	"hjy_CO_title": "二氧化碳",
	"hjy_EMR_title": "电磁辐射",
	"hjy_EMR_desc": "实时",
	// 环境仪城市界面
	"hjy_city_title": "城市PM2.5排名",
	"hjy_city_temperature": "室外&nbsp;&nbsp;温度",
	"hjy_city_title2": "今日全国最优",
	"hjy_city_tabTitle1": "排名",
	"hjy_city_tabTitle2": "城市",
	"hjy_city_tabTitle3": "PM2.5浓度μg/m³",
	"hjy_city_tabTitle4": "污染等级",
	"hjy_city_previous": "上一页",
	"hjy_city_next": "下一页",
	"hjy_city_desc1": "*数据取自",
	"hjy_city_desc2": "中国环境监测总站",
	"hjy_city_desc3": "更新",

	// 新风肺保
	"fb_main_level": "档",
	"fb_main_desc1": "粗效已使用",
	"fb_main_desc2": "高效过滤器已使用",
	"fb_main_reset": "清零",
	"fb_main_timeS": "小时",
	"fb_main_timeS2": "h",
	// 新风肺保设置页面
	"fb_set_title1": "参数设置",
	"fb_set_t1_cx": "粗效清洗周期：",
	"fb_set_t1_gx": "高效过滤器更换周期：",
	"fb_set_t1_fctj": "粉尘调节值：",
	"fb_set_t1_fcbj": "粉尘报警值：",
	"fb_set_t1_tj": "调节值：",
	"fb_set_t1_bj": "报警值：",
	"fb_set_title2": "人离关机时间设置",
	"fb_set_flag_enable": "有效",
	"fb_set_flag_disable": "无效",
	"fb_set_title3": "粉尘调节",
	"fb_set_title4": "调节",

	// 新风机首页
	"xfj_main_title1": "设备",
	"xfj_main_title2": "能耗",
	"xfj_main_title3": "故障",
	// 新风机主页
	"xfj_li_newWind": "新风",
	"xfj_li_co2": "二氧化碳",
	"xfj_li_indoor": "室内",
	"xfj_li_outdoor": "室外",
	"xfj_li_exhaust": "排风",
	"xfj_model_title": "控制模式",
	"xfj_model_control": "新鲜度自控",
	"xfj_model_default": "常规",
	"xfj_model_max": "强风",
	"xfj_model_min": "静音",
	"xfj_model_nobody": "无人",
	"xfj_model_winter": "极寒天（≤-16℃）",
	"xfj_desc_cx": "粗效已使用：",
	"xfj_desc_jdcc": "静电除尘已使用：",
	"xfj_desc_gx": "高效过滤器已使用：",
	"xfj_desc_small": "（建议720h后清洗）",
	// 新风机二级页面
	"xfj_set_cx": "粗效使用时间",
	"xfj_set_jd": "静电使用时间",
	"xfj_set_gx": "高效过滤器使用时间",
	"xfj_set_retBtn": "清零",
	"xfj_set_outDoorT": "绑定室外城市检测数据",
	"xfj_set_cityT": "城市",
	"xfj_set_fc": "粉尘调节",
	"xfj_set_flag_enable": "有效",
	"xfj_set_flag_disable": "无效",
	// 新风机能耗
	"xfj_ec_title": "能耗",
	"xfj_ec_tabT1": "时间",
	"xfj_ec_tabT2": "热回收",
	"xfj_ec_tabT3": "风机电耗",
	"xfj_ec_cellSS": "实时(kW)",
	"xfj_ec_cellXL": "效率",
	"xfj_ec_cellTD": "今天(kWh)",
	"xfj_ec_cellTM": "本月(kWh)",
	"xfj_ec_cellTY": "今年(kWh)",
	"xfj_ec_cellLY": "去年(kWh)",
	// 新风机故障
	"xfj_fault_title": "异常/故障",

	// 二维码扫描
	"scan_title": "二维码扫描",
	"scan_photo": "从相册选取二维码",
	"scan_cancel": "取　 消",

	/*我的模块*/
	"mine_accountM": "账号管理",
	"mine_infoM": "信息",
	"mine_helpM": "使用帮助",
	"mine_salesInfo": "售后维修",
	"mine_aboutM": "关于",
	"mine_buyS": "一键购买",
	"mine_about_Version": "当前版本：",

	// 账号管理
	"mine_accountM_info": "注册账号",
	"mine_accountM_locationInfo": "地址信息",
	"mine_accountM_position": "自动定位",
	"mine_accountM_province": "省份：",
	"mine_accountM_city": "城市：",
	"mine_accountM_area": "区/县：",
	"mine_accountM_street": "街道：",
	"mine_accountM_saveBtn": "保存",
	
	// 售后维修
	"mine_sales_deviceM": "设备型号：",
	"mine_sales_pDesc": "故障描述：",
	"mine_sales_photoT": "照片：",
	"mine_sales_photoDesc": "（最多上传三张）",
	"mine_sales_phoneNum": "联系电话：",
	"mine_sales_name": "联系人：",
	"mine_sales_address": "联系地址：",
	"mine_sales_submit": "提交",
	
	//使用帮助
	"mine_help_text1": "1. 注册用户：利用手机号码(或邮箱)进行注册，提交注册的过程中手机(或邮箱)会接收到短信校验码，正确填写短信校验码后，填写登录密码后提交信息，完成注册。",
	"mine_help_text2": "2. 忘记密码：如果用户遗忘登录密码，可通过主界面中的“忘记密码”取回自己的密码，在取回密码过程中需要填写注册手机号码(或邮箱)，并正确填写接收到的短信验证码，再填写新的登录密码，提交信息完成密码重置。",
	"mine_help_text3": "3. 修改密码：可通过忘记密码来实现密码修改。",
	"mine_help_text4": "4. 设备绑定：在执行设备绑定时，需先让被绑定的设备连接互联网的Wifi。然后进入软件对应的选项（环境仪、新风机、新风肺保），添加设备到系统中。其中仅环境仪只需填写环境仪的MAC地址即可，其它的设备均需填写对应定位信息和当前环境下Wifi的密码然后执行绑定。",
	"mine_help_text5": "5. 设备控制：设备完成绑定后，手机端可在其它的网络环境中远程控制操作已绑定的设备，以及提取对应的信息。其中环境仪需保持充电模式，否则环境仪将会在待机时切断网络连接。",
	"mine_help_text6": "6. 共享控制：所有绑定的设备均可多用户共享控制，共享控制由绑定用户发起向已注册用户分享控制权限（已注册用户不用绑定设备即可具备与已绑定用户类似的设备控制功能权限）。接受共享控制的用户可主动接受或拒绝共享邀请，也可以解除已接受的共享控制。",
	"mine_help_text7": "7. 软件更新：软件采用自动检测新版本，然后提醒用户执行软件下载并更新。",
	// 其他
	"other_cancel": "取消",
	"other_sure": "确认",
	"other_selectT": "请选择",
});


$(function() {
	window.SwaggerTranslator.translate();
});
